km3modules.common.MemoryObserver
================================

.. currentmodule:: km3modules.common

.. autoclass:: MemoryObserver

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MemoryObserver.__init__
      ~MemoryObserver.add
      ~MemoryObserver.configure
      ~MemoryObserver.expose
      ~MemoryObserver.finish
      ~MemoryObserver.get
      ~MemoryObserver.pre_finish
      ~MemoryObserver.process
      ~MemoryObserver.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MemoryObserver.name
   
   